@@ -38,22 +38,21 @@ namespace PdfMod.Gui
 {
     public class Actions : HyenaActionGroup
     {
-        private Client app;
-        private UndoManager undo_manager;
-        private const string WIKI_URL = "http://live.gnome.org/PdfMod";
+        Client app;
+        UndoManager undo_manager;
+        const string WIKI_URL = "http://live.gnome.org/PdfMod";
+        const string DOCS_URL = "http://library.gnome.org/users/pdfmod/";
 
-        private static string [] require_doc_actions = new string[] {
+        static string [] require_doc_actions = new string[] {
             "Save", "SaveAs", "Properties", "Undo", "Redo", "ZoomFit", "OpenInViewer",
-            "SelectAll", "SelectEvens", "SelectOdds", "SelectMatching", "InsertFrom", "ExportImages"
+            "SelectAll", "SelectEvens", "SelectOdds", "SelectMatching", "SelectInverse", "InsertFrom", "ExportImages"
         };
 
-        private static string [] require_page_actions = new string[] {
+        static string [] require_page_actions = new string[] {
             "Remove", "Extract", "RotateRight", "RotateLeft"
         };
 
-        public UndoManager UndoManager {
-            get { return undo_manager; }
-        }
+        public UndoManager UndoManager { get { return undo_manager; } }
 
         public Actions (Client app, ActionManager action_manager) : base (action_manager, "Global")
         {
@@ -80,6 +79,7 @@ namespace PdfMod.Gui
                 new ActionEntry ("SelectEvens", null, Catalog.GetString ("Select Even Pages"), null, null, OnSelectEvens),
                 new ActionEntry ("SelectOdds", null, Catalog.GetString ("Select Odd Pages"), null, null, OnSelectOdds),
                 new ActionEntry ("SelectMatching", null, Catalog.GetString ("Select Matching..."), "<control>F", null, OnSelectMatching),
+                new ActionEntry ("SelectInverse", null, Catalog.GetString ("_Invert Selection"), "<shift><control>I", null, OnSelectInverse),
                 new ActionEntry ("Undo", Stock.Undo, null, "<control>z", null, OnUndo),
                 new ActionEntry ("Redo", Stock.Redo, null, "<control>y", null, OnRedo),
 
@@ -138,6 +138,9 @@ namespace PdfMod.Gui
             item = ActionManager.UIManager.GetWidget ("/MainMenu/FileMenu/Close");
             item.AddAccelerator ("activate", ActionManager.UIManager.AccelGroup, (uint) Gdk.Key.q, Gdk.ModifierType.ControlMask, Gtk.AccelFlags.Visible);
 
+            item = ActionManager.UIManager.GetWidget ("/MainMenu/EditMenu/Redo");
+            item.AddAccelerator ("activate", ActionManager.UIManager.AccelGroup, (uint) Gdk.Key.z, Gdk.ModifierType.ControlMask | Gdk.ModifierType.ShiftMask, Gtk.AccelFlags.Visible);
+
             // Set up recent documents menu
             MenuItem recent_item = ActionManager.UIManager.GetWidget ("/MainMenu/FileMenu/RecentMenu") as MenuItem;
             var recent_chooser_item = new RecentChooserMenu (RecentManager.Default) {
@@ -151,12 +154,12 @@ namespace PdfMod.Gui
             recent_item.Submenu = recent_chooser_item;
         }
 
-        private void OnChanged (object o, EventArgs args)
+        void OnChanged (object o, EventArgs args)
         {
             Update ();
         }
 
-        private void Update ()
+        void Update ()
         {
             bool have_doc = app.Document != null;
             foreach (string action in require_doc_actions)
@@ -200,15 +203,17 @@ namespace PdfMod.Gui
 
 #region Action Handlers
 
-        private void OnOpen (object o, EventArgs args)
+        void OnOpen (object o, EventArgs args)
         {
-            var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Select PDF"), app.Window, FileChooserAction.Open);
+            var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Select PDF"), app.Window, FileChooserAction.Open) {
+                SelectMultiple = true,
+                DefaultResponse = ResponseType.Ok
+            };
             chooser.AddFilter (GtkUtilities.GetFileFilter (Catalog.GetString ("PDF Documents"), new string [] {"pdf"}));
             chooser.AddFilter (GtkUtilities.GetFileFilter (Catalog.GetString ("All Files"), new string [] {"*"}));
-            chooser.SelectMultiple = false;
             chooser.AddButton (Stock.Cancel, ResponseType.Cancel);
             chooser.AddButton (Stock.Open, ResponseType.Ok);
-            chooser.DefaultResponse = ResponseType.Ok;
+
             if (app.Document != null) {
                 chooser.SetCurrentFolder (System.IO.Path.GetDirectoryName (app.Document.SuggestedSavePath));
             } else {
@@ -216,20 +221,24 @@ namespace PdfMod.Gui
             }
 
             var response = chooser.Run ();
-            string filename = chooser.Filename;
+            var filenames = chooser.Filenames;
             chooser.Destroy ();
 
             if (response == (int)ResponseType.Ok) {
-                Client.RunIdle (delegate { app.LoadPath (filename); });
+                Client.RunIdle (delegate {
+                    foreach (var file in filenames) {
+                        app.LoadPath (file);
+                    }
+                });
             }
         }
 
-        private void OnOpenInViewer (object o, EventArgs args)
+        void OnOpenInViewer (object o, EventArgs args)
         {
             System.Diagnostics.Process.Start (app.Document.CurrentStateUri);
         }
 
-        private void OnFullScreenView (object o, EventArgs args)
+        void OnFullScreenView (object o, EventArgs args)
         {
             bool fullscreen = (this["FullScreenView"] as ToggleAction).Active;
 
@@ -240,16 +249,17 @@ namespace PdfMod.Gui
             }
         }
 
-        private void OnInsertFrom (object o, EventArgs args)
+        void OnInsertFrom (object o, EventArgs args)
         {
-            var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Select PDF"), app.Window, FileChooserAction.Open);
+            var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Select PDF"), app.Window, FileChooserAction.Open) {
+                SelectMultiple = false,
+                DefaultResponse = ResponseType.Ok
+            };
             chooser.AddFilter (GtkUtilities.GetFileFilter ("PDF Documents", new string [] {"pdf"}));
             chooser.AddFilter (GtkUtilities.GetFileFilter (Catalog.GetString ("All Files"), new string [] {"*"}));
-            chooser.SelectMultiple = false;
             chooser.SetCurrentFolder (System.IO.Path.GetDirectoryName (app.Document.SuggestedSavePath));
             chooser.AddButton (Stock.Cancel, ResponseType.Cancel);
             chooser.AddButton (Stock.Open, ResponseType.Ok);
-            chooser.DefaultResponse = ResponseType.Ok;
 
             var response = chooser.Run ();
             string filename = chooser.Filename;
@@ -260,24 +270,25 @@ namespace PdfMod.Gui
             }
         }
 
-        private void OnSave (object o, EventArgs args)
+        void OnSave (object o, EventArgs args)
         {
             app.Document.Save (app.Document.SuggestedSavePath);
             undo_manager.Clear ();
         }
 
-        private void OnSaveAs (object o, EventArgs args)
+        void OnSaveAs (object o, EventArgs args)
         {
-            var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Save as..."), app.Window, FileChooserAction.Save);
-            chooser.SelectMultiple = false;
-            chooser.DoOverwriteConfirmation = true;
+            var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Save as..."), app.Window, FileChooserAction.Save) {
+                SelectMultiple = false,
+                DoOverwriteConfirmation = true,
+                CurrentName = System.IO.Path.GetFileName (app.Document.SuggestedSavePath),
+                DefaultResponse = ResponseType.Ok
+            };
             chooser.AddButton (Stock.Cancel, ResponseType.Cancel);
             chooser.AddButton (Stock.SaveAs, ResponseType.Ok);
             chooser.AddFilter (GtkUtilities.GetFileFilter ("PDF Documents", new string [] {"pdf"}));
             chooser.AddFilter (GtkUtilities.GetFileFilter (Catalog.GetString ("All Files"), new string [] {"*"}));
             chooser.SetCurrentFolder (System.IO.Path.GetDirectoryName (app.Document.SuggestedSavePath));
-            chooser.CurrentName = System.IO.Path.GetFileName (app.Document.SuggestedSavePath);
-            chooser.DefaultResponse = ResponseType.Ok;
 
             var response = chooser.Run ();
             string filename = chooser.Filename;
@@ -290,7 +301,7 @@ namespace PdfMod.Gui
             }
         }
 
-        private void OnProperties (object o, EventArgs args)
+        void OnProperties (object o, EventArgs args)
         {
             app.EditorBox.Visible = (this["Properties"] as ToggleAction).Active;
             if (app.EditorBox.Visible) {
@@ -298,7 +309,7 @@ namespace PdfMod.Gui
             }
         }
 
-        private void OnRemove (object o, EventArgs args)
+        void OnRemove (object o, EventArgs args)
         {
             var action = new RemoveAction (app.Document, app.IconView.SelectedPages);
             action.Do ();
@@ -306,7 +317,7 @@ namespace PdfMod.Gui
             //undo_manager.AddUndoAction (action);
         }
 
-        private void OnExtractPages (object o, EventArgs args)
+        void OnExtractPages (object o, EventArgs args)
         {
             var doc = new PdfDocument ();
             var pages = new List<Page> (app.IconView.SelectedPages);
@@ -326,7 +337,7 @@ namespace PdfMod.Gui
             ));
         }
 
-        private void OnExportImages (object o, EventArgs args)
+        void OnExportImages (object o, EventArgs args)
         {
             var action = new ExportImagesAction (app.Document, app.Document.Pages);
             if (action.ExportableImageCount == 0) {
@@ -357,20 +368,20 @@ namespace PdfMod.Gui
             System.Diagnostics.Process.Start (export_path);
         }
 
-        private void OnUndo (object o, EventArgs args)
+        void OnUndo (object o, EventArgs args)
         {
             undo_manager.Undo ();
         }
 
-        private void OnRedo (object o, EventArgs args)
+        void OnRedo (object o, EventArgs args)
         {
             undo_manager.Redo ();
         }
 
         [DllImport ("glib-2.0.dll")]
-        private static extern IntPtr g_get_language_names ();
+        static extern IntPtr g_get_language_names ();
 
-        private string CombinePaths (params string [] parts)
+        string CombinePaths (params string [] parts)
         {
             string path = parts[0];
             for (int i = 1; i < parts.Length; i++) {
@@ -379,7 +390,7 @@ namespace PdfMod.Gui
             return path;
         }
 
-        private void OnHelp (object o, EventArgs args)
+        void OnHelp (object o, EventArgs args)
         {
             bool shown = false;
             try {
@@ -418,12 +429,12 @@ namespace PdfMod.Gui
                 var response = (ResponseType) message_dialog.Run ();
                 message_dialog.Destroy ();
                 if (response == ResponseType.Yes) {
-                    System.Diagnostics.Process.Start (WIKI_URL);
+                    System.Diagnostics.Process.Start (DOCS_URL);
                 }
             }
         }
 
-        private void OnAbout (object o, EventArgs args)
+        void OnAbout (object o, EventArgs args)
         {
             Gtk.AboutDialog.SetUrlHook ((dlg, link) => { System.Diagnostics.Process.Start (link); });
 
@@ -476,63 +487,68 @@ namespace PdfMod.Gui
             dialog.Destroy ();
         }
 
-        private void OnPageContextMenu (object o, EventArgs args)
+        void OnPageContextMenu (object o, EventArgs args)
         {
             ShowContextMenu ("/PageContextMenu");
         }
 
-        private void OnSelectAll (object o, EventArgs args)
+        void OnSelectAll (object o, EventArgs args)
         {
             app.IconView.SetPageSelectionMode (PageSelectionMode.All);
         }
 
-        private void OnSelectEvens (object o, EventArgs args)
+        void OnSelectEvens (object o, EventArgs args)
         {
             app.IconView.SetPageSelectionMode (PageSelectionMode.Evens);
         }
 
-        private void OnSelectOdds (object o, EventArgs args)
+        void OnSelectOdds (object o, EventArgs args)
         {
             app.IconView.SetPageSelectionMode (PageSelectionMode.Odds);
         }
 
-        private void OnSelectMatching (object o, EventArgs args)
+        void OnSelectMatching (object o, EventArgs args)
         {
             app.ToggleMatchQuery ();
         }
 
-        private void OnZoomIn (object o, EventArgs args)
+        void OnSelectInverse (object o, EventArgs args)
+        {
+            app.IconView.SetPageSelectionMode (PageSelectionMode.Inverse);
+        }
+
+        void OnZoomIn (object o, EventArgs args)
         {
             app.IconView.Zoom (10);
         }
 
-        private void OnZoomOut (object o, EventArgs args)
+        void OnZoomOut (object o, EventArgs args)
         {
             app.IconView.Zoom (-10);
         }
 
-        private void OnZoomFit (object o, EventArgs args)
+        void OnZoomFit (object o, EventArgs args)
         {
             app.IconView.ZoomFit ();
         }
 
-        private void OnViewToolbar (object o, EventArgs args)
+        void OnViewToolbar (object o, EventArgs args)
         {
             bool show = (this["ViewToolbar"] as ToggleAction).Active;
             Client.Configuration.ShowToolbar = app.HeaderToolbar.Visible = show;
         }
 
-        private void OnRotateRight (object o, EventArgs args)
+        void OnRotateRight (object o, EventArgs args)
         {
             Rotate (90);
         }
 
-        private void OnRotateLeft (object o, EventArgs args)
+        void OnRotateLeft (object o, EventArgs args)
         {
             Rotate (-90);
         }
 
-        private void Rotate (int degrees)
+        void Rotate (int degrees)
         {
             if (!(app.Window.Focus is Gtk.Entry)) {
                 var action = new RotateAction (app.Document, app.IconView.SelectedPages, degrees);
@@ -541,7 +557,7 @@ namespace PdfMod.Gui
             }
         }
 
-        private void OnClose (object o, EventArgs args)
+        void OnClose (object o, EventArgs args)
         {
             app.Quit ();
         }
